@@ -444,7 +444,7 @@ class Device(Events):
         刷新当前设备的UI布局信息。\n
         :return: 无
         """
-        self.xml_string = str(self.con.get(path="getLayoutXML").read(), 'utf-8')
+        self.xml_string = str(self.con.get(path="getLayoutXML").read(), 'utf-8').replace('\x08', '')
 
     def os_version(self) -> str:
         """
